@@ -18,6 +18,7 @@ from botx.bots.mixins import (
 from botx.clients.clients import async_client, sync_client as synchronous_client
 from botx.collecting.collectors.collector import Collector
 from botx.dependencies.models import Depends
+from botx.middlewares.authorization import AuthorizationMiddleware
 from botx.middlewares.exceptions import ExceptionMiddleware
 from botx.models import credentials, datastructures, menu
 from botx.models.messages.message import Message
@@ -34,7 +35,7 @@ class Bot(  # noqa: WPS215
     """Class that implements bot behaviour."""
 
     dependencies: InitVar[List[Depends]] = field(default=None)
-    known_hosts: List[credentials.ExpressServer] = field(default_factory=list)
+    bot_accounts: List[credentials.BotXCredentials] = field(default_factory=list)
     startup_events: List[typing.BotLifespanEvent] = field(default_factory=list)
     shutdown_events: List[typing.BotLifespanEvent] = field(default_factory=list)
 
@@ -44,7 +45,8 @@ class Bot(  # noqa: WPS215
     exception_middleware: ExceptionMiddleware = field(init=False)
     state: datastructures.State = field(init=False)
     dependency_overrides: Dict[Callable, Callable] = field(
-        init=False, default_factory=dict,
+        init=False,
+        default_factory=dict,
     )
 
     tasks: Set[asyncio.Future] = field(init=False, default_factory=set)
@@ -67,7 +69,8 @@ class Bot(  # noqa: WPS215
         self.client = async_client.AsyncClient()
         self.sync_client = synchronous_client.Client()
         self.collector = Collector(
-            dependencies=dependencies, dependency_overrides_provider=self,
+            dependencies=dependencies,
+            dependency_overrides_provider=self,
         )
         self.exception_middleware = ExceptionMiddleware(self.collector)
 
@@ -79,6 +82,7 @@ class Bot(  # noqa: WPS215
             exceptions.NoMatchFound,
             exception_handlers.no_match_found_exception_handler,
         )
+        self.add_middleware(AuthorizationMiddleware)
 
     async def status(self, *args: Any, **kwargs: Any) -> menu.Status:
         """Generate status object that could be return to BotX API on `/status`.
@@ -96,7 +100,9 @@ class Bot(  # noqa: WPS215
         for handler in self.handlers:
             if callable(handler.include_in_status):
                 include_in_status = await concurrency.callable_to_coroutine(
-                    handler.include_in_status, *args, **kwargs,
+                    handler.include_in_status,
+                    *args,
+                    **kwargs,
                 )
             else:
                 include_in_status = handler.include_in_status
@@ -117,15 +123,21 @@ class Bot(  # noqa: WPS215
 
         Arguments:
             message: incoming message to bot.
-
-        Raises:
-            ServerUnknownError: raised if message was received from unregistered host.
         """
         logger.bind(botx_bot=True, payload=message).debug("process incoming message")
         msg = Message.from_dict(message, self)
-        for server in self.known_hosts:
-            if server.host == msg.host:
-                await self(msg)
-                break
-        else:
-            raise exceptions.ServerUnknownError(host=msg.host)
+
+        # raise UnknownBotError if not registered.
+        self.get_account_by_bot_id(msg.bot_id)
+
+        await self(msg)
+
+    async def authorize(self) -> None:
+        """Process auth for each bot account."""
+        for account in self.bot_accounts:
+            token = await self.get_token(
+                account.host,
+                account.bot_id,
+                account.signature,
+            )
+            account.token = token
