@@ -1,17 +1,17 @@
 """Definition for sync client for BotX API."""
 from dataclasses import field
-from typing import Any, List, Optional, TypeVar
+from http import HTTPStatus
+from typing import Any, List, TypeVar
 
 import httpx
-from httpx import Response
-from loguru import logger
 from pydantic.dataclasses import dataclass
 
 from botx import concurrency
 from botx.clients.clients.processing import extract_result, handle_error
 from botx.clients.methods.base import BotXMethod, ErrorHandlersInMethod
+from botx.clients.methods.wrappers import HTTPRequest, HTTPResponse
 from botx.converters import optional_sequence_to_list
-from botx.exceptions import BotXAPIError
+from botx.exceptions import BotXAPIError, BotXAPIRouteDeprecated
 from botx.shared import BotXDataclassConfig
 
 ResponseT = TypeVar("ResponseT")
@@ -29,56 +29,69 @@ class Client:
         self.http_client = httpx.Client()
         self.interceptors = optional_sequence_to_list(self.interceptors)
 
-    def call(
-        self, method: BotXMethod[ResponseT], host: Optional[str] = None,
-    ) -> ResponseT:
-        """Make request to BotX API using passed method and return result.
+    @classmethod
+    def build_request(cls, method: BotXMethod[ResponseT]) -> HTTPRequest:
+        """Build HTTPRequest from passed BotX method.
 
         Arguments:
-            method: BotX API method that should be called.
-            host: override for host from method.
+            method: BotX method.
+
+        Returns:
+            Built request.
+        """
+        return method.build_http_request()
+
+    def process_response(
+        self,
+        method: BotXMethod[ResponseT],
+        response: HTTPResponse,
+    ) -> ResponseT:
+        """Handle errors and extract data from BotX API response.
+
+        Arguments:
+            method: BotX API method.
+            response: HTTPResponse that is result of method executing.
 
         Returns:
             Shape specified for method response.
 
         Raises:
             BotXAPIError: raised if handler for error status code was not found.
+            BotXAPIRouteDeprecated: raised if API route was deprecated.
         """
-        if host is not None:
-            method.host = host
-
-        response = self.execute(method)
-
-        if httpx.codes.is_error(response.status_code):
+        if response.is_error or response.is_redirect:
             handlers_dict = method.error_handlers
             error_handlers = handlers_dict.get(response.status_code)
             if error_handlers is not None:
                 _handle_error(method, error_handlers, response)
 
+            if response.status_code == HTTPStatus.GONE:
+                raise BotXAPIRouteDeprecated(
+                    url=method.url,
+                    method=method.http_method,
+                    status=response.status_code,
+                    response_content=response.json_body,
+                )
+
             raise BotXAPIError(
                 url=method.url,
                 method=method.http_method,
                 status=response.status_code,
-                response_content=response.json(),
+                response_content=response.json_body,
             )
 
         return extract_result(method, response)
 
-    def execute(self, method: BotXMethod) -> Response:
-        """Make real HTTP request using client.
+    def execute(self, request: HTTPRequest) -> HTTPResponse:
+        """Make request to BotX API.
 
         Arguments:
-            method: BotX API method that should be called.
+            request: HTTPRequest that was built from method.
 
         Returns:
             HTTP response from API.
         """
-        request = method.build_http_request()
-        method_name = method.__repr_name__()  # noqa: WPS609
-        logger.bind(botx_client=True, payload=request.to_dict()).debug(
-            "send {0} request", method_name,
-        )
-        return self.http_client.request(
+        response = self.http_client.request(
             request.method,
             request.url,
             headers=request.headers,
@@ -86,8 +99,16 @@ class Client:
             content=request.request_data,
         )
 
+        return HTTPResponse(
+            status_code=response.status_code,
+            bytes_body=response.content,
+            json_body=response.json(),
+        )
+
 
 def _handle_error(
-    method: BotXMethod, error_handlers: ErrorHandlersInMethod, response: Response,
+    method: BotXMethod,
+    error_handlers: ErrorHandlersInMethod,
+    response: HTTPResponse,
 ) -> None:
     concurrency.async_to_sync(handle_error)(method, error_handlers, response)
