@@ -2,10 +2,10 @@
 from typing import NoReturn
 from uuid import UUID
 
-from httpx import Response
 from pydantic import BaseModel
 
 from botx.clients.methods.base import APIErrorResponse, BotXMethod
+from botx.clients.methods.wrappers import HTTPResponse
 from botx.exceptions import BotXAPIError
 
 
@@ -25,7 +25,7 @@ class ChatCreationDisallowedData(BaseModel):
     bot_id: UUID
 
 
-def handle_error(method: BotXMethod, response: Response) -> NoReturn:
+def handle_error(method: BotXMethod, response: HTTPResponse) -> NoReturn:
     """Handle "chat creating disallowed" error response.
 
     Arguments:
@@ -36,13 +36,13 @@ def handle_error(method: BotXMethod, response: Response) -> NoReturn:
         ChatCreationDisallowedError: raised always.
     """
     parsed_response = APIErrorResponse[ChatCreationDisallowedData].parse_obj(
-        response.json(),
+        response.json_body,
     )
     error_data = parsed_response.error_data
     raise ChatCreationDisallowedError(
         url=method.url,
         method=method.http_method,
-        response_content=response.content,
+        response_content=response.bytes_body,
         status_content=response.status_code,
         bot_id=error_data.bot_id,
     )
