@@ -25,9 +25,10 @@ class BotDisabledResponse(BotXBaseModel):
 
     errors: List[str] = []
 
-    @validator("error_data", always=True, whole=True)
+    @validator("error_data", always=True, each_item=True)
     def status_message_in_error_data(
-        cls, error_data: Dict[str, Any],  # noqa: N805
+        cls,
+        error_data: Dict[str, Any],  # noqa: N805
     ) -> Union[BotDisabledErrorData, Dict[str, Any]]:
         """Check that value contains `status_message` key or field.
 
